DataType

Enum DataType 

pub enum DataType {
    Primitive(Primitive),
    List(List),
    Map(Map),
    Struct(Struct),
    Enum(Enum),
    Tuple(Tuple),
    Nullable(Box<DataType>),
    Intersection(Vec<DataType>),
    Generic(Generic),
    Reference(Reference),
}
Runtime type-erased representation of a Rust type.

A language exporter takes this general format and converts it into a language specific syntax.

Variants



Primitive(Primitive)

A primitive scalar type like integers, floats, booleans, chars, or strings.



List(List)

A sequential collection type.



Map(Map)

A map/dictionary type.



Struct(Struct)

A struct type with named, unnamed, or unit fields.



Enum(Enum)

An enum type.



Tuple(Tuple)

A tuple type.



Nullable(Box<DataType>)

A nullable wrapper around another type.



Intersection(Vec<DataType>)

A structural intersection of multiple object-like types.



Generic(Generic)

A placeholder for a generic type defined on the parent NamedDataType. Rendered as T. These should never be returned from Type::definition, they should only appear in NamedDataType’s ty field.



Reference(Reference)

A reference to another named or opaque type.