pub struct DataTypeReference {
pub name: &'static str,
pub sid: TypeSid,
pub generics: Vec<DataType>,
}Expand description
A reference to a DataType that can be used before a type is resolved in order to
support recursive types without causing an infinite loop.
This works since a child type that references a parent type does not care about the parent’s fields, only really its name. Once all of the parent’s fields have been resolved will the parent’s definition be placed in the type map.
Fields
name: &'static strsid: TypeSidgenerics: Vec<DataType>Trait Implementations
Sourceimpl Clone for DataTypeReference
impl Clone for DataTypeReference
Sourcefn clone(&self) -> DataTypeReference
fn clone(&self) -> DataTypeReference
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataTypeReference
impl Debug for DataTypeReference
Sourceimpl PartialEq for DataTypeReference
impl PartialEq for DataTypeReference
impl StructuralPartialEq for DataTypeReference