pub struct ExportConfiguration { /* private fields */ }Available on crate feature
typescript only.Expand description
Options for controlling the behavior of the Typescript exporter.
Implementations
Sourceimpl ExportConfiguration
impl ExportConfiguration
Sourcepub fn bigint(self, bigint: BigIntExportBehavior) -> Self
pub fn bigint(self, bigint: BigIntExportBehavior) -> Self
Configure the BigInt handling behaviour
Sourcepub fn comment_style(self, exporter: Option<CommentFormatterFn>) -> Self
pub fn comment_style(self, exporter: Option<CommentFormatterFn>) -> Self
Configure a function which is responsible for styling the comments to be exported
Sourcepub fn export_by_default(self, x: Option<bool>) -> Self
pub fn export_by_default(self, x: Option<bool>) -> Self
Configure whether or not to export types by default.
This can be overridden on a specific type by using #[specta(export)].
This parameter only takes effect when this configuration if passed into export::ts_with_cfg