pub struct ResolvedTypes(/* private fields */);Expand description
A wrapper around Types indicating the type graph has already been
transformed for a specific export format.
This is generally constructed by a format crate (for example
specta-serde) after applying
format-specific rewrites.
Constructing this wrapper from plain Types is explicit because the
conversion may change type shapes. Prefer using your format crate’s
conversion entry points when possible.
Implementations
Sourceimpl ResolvedTypes
impl ResolvedTypes
Sourcepub fn from_resolved_types(types: Types) -> Self
pub fn from_resolved_types(types: Types) -> Self
Wrap already-resolved Types as ResolvedTypes.
This should generally be called by format crates after they finish their
own transformation pass (for example specta_serde::apply or
specta_serde::apply_phases).
If you call this in end-user code your types may not look how you expect!
Sourcepub fn into_types(self) -> Types
pub fn into_types(self) -> Types
Consume ResolvedTypes and return the underlying Types.
Notes
This does not undo format-specific resolution. The returned Types
remain whatever shape they were resolved into.
Sourcepub fn into_sorted_iter(&self) -> impl ExactSizeIterator<Item = &NamedDataType>
pub fn into_sorted_iter(&self) -> impl ExactSizeIterator<Item = &NamedDataType>
Sort the collection into a consistent order and return an iterator.
The sort order is not necessarily guaranteed to be stable between versions but currently we sort by name.
This method requires reallocating the map to sort the collection. You should prefer Self::into_unsorted_iter if you don’t care about the order.
Sourcepub fn into_unsorted_iter(
&self,
) -> impl ExactSizeIterator<Item = &NamedDataType>
pub fn into_unsorted_iter( &self, ) -> impl ExactSizeIterator<Item = &NamedDataType>
Return the unsorted iterator over the collection.
Sourcepub fn iter_mut<F>(&mut self, f: F)where
F: FnMut(&mut NamedDataType),
pub fn iter_mut<F>(&mut self, f: F)where
F: FnMut(&mut NamedDataType),
Return an mutable iterator over the type collection. Note: The order returned is unsorted.